Enum WireError

pub enum WireError {
Show 24 variants Blockchain(BlockchainError), ChannelSend(SendError<NodeRequest>), PeerError(PeerError), CoinbaseNotMatured, PeerNotFound, NoPeersAvailable, PeerMisbehaving, AnchorFileNotFound, PeerAlreadyExists(IpAddr, u16), PeerNotFoundAtAddress(IpAddr, u16), Io(Error), Serde(Error), NoUtreexoPeersAvailable, NoPeerToSendRequest, PeerTimeout, CompactBlockFiltersError(IterableFilterStoreError), PoisonedLock, InvalidAddress(AddrParseError), Transport(TransportError), ResponseSendError, NoAddressesAvailable, BlockNotFound, BlockProofNotFound, LeafDataNotFound,
}

Variants



Blockchain(BlockchainError)

Blockchain-related error.

This error kind is returned by our ChainState.



ChannelSend(SendError<NodeRequest>)

Error while writing into a channel



PeerError(PeerError)

Peer error



CoinbaseNotMatured

Coinbase isn’t mature



PeerNotFound

Peer not found in our current connections



NoPeersAvailable

We don’t have any peers that could fulfill such request.



PeerMisbehaving

Our peer is misbehaving



AnchorFileNotFound

Failed to init Utreexo peers: anchors.json does not exist yet



PeerAlreadyExists(IpAddr, u16)

Peer already exists in our peers list



PeerNotFoundAtAddress(IpAddr, u16)

Peer not found with this given address and port, in our peer list



Io(Error)

Generic io error



Serde(Error)

JSON (de)serialization error



NoUtreexoPeersAvailable

Failed to save Utreexo peers: no peers to save to anchors.json



NoPeerToSendRequest

We couldn’t find a peer to send a request



PeerTimeout

Peer timed out some request



CompactBlockFiltersError(IterableFilterStoreError)

Compact block filters storage error



PoisonedLock

Poisoned lock



InvalidAddress(AddrParseError)

We couldn’t parse the provided address



Transport(TransportError)

Transport error



ResponseSendError

Can’t send back response for user request



NoAddressesAvailable

No addresses available to connect to



BlockNotFound

We tried to work on a block we don’t have. This is a bug!



BlockProofNotFound

We tried to work on a block that we don’t have a proof for yet. This is a bug!



LeafDataNotFound

Couldn’t find the leaf data for a block